==> gatsby-plugin-fela-0.0.6.tgz: package/gatsby-ssr.js <==
"use strict";

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _server = require("react-dom/server");

var _reactFela = require("react-fela");

var _fela = require("fela");

var _felaDom = require("fela-dom");

var _fs = require("fs");

var _fs2 = _interopRequireDefault(_fs);

var _eval2 = require("eval");

var _eval3 = _interopRequireDefault(_eval2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.replaceRenderer = function (_ref, pluginOptions) {
  var bodyComponent = _ref.bodyComponent,
      replaceBodyHTMLString = _ref.replaceBodyHTMLString,
      setHeadComponents = _ref.setHeadComponents;

  var config = void 0;
  try {
    config = eval(_fs2.default.readFileSync('./fela.config.js', 'utf8'));
  } catch (err) {
    console.log(err);
  }
  var renderer = (0, _fela.createRenderer)(config);
  var bodyHTML = (0, _server.renderToString)(_react2.default.createElement(
    _reactFela.Provider,
    { renderer: renderer },
    bodyComponent
  ));
  var sheetList = (0, _felaDom.renderToSheetList)(renderer);
  var elements = sheetList.map(function (_ref2) {
    var type = _ref2.type,
        css = _ref2.css,
        media = _ref2.media,
        support = _ref2.support;
    return _react2.default.createElement("style", {
      dangerouslySetInnerHTML: { __html: css },
      "data-fela-type": type,
      "data-fela-support": support,
      key: type + "-" + media,
      media: media
    });
  });
  replaceBodyHTMLString(bodyHTML);
  setHeadComponents(elements);
};

==> gatsby-plugin-fela-0.0.7.tgz: package/gatsby-ssr.js <==
"use strict";

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _server = require("react-dom/server");

var _reactFela = require("react-fela");

var _fela = require("fela");

var _felaDom = require("fela-dom");

var _fs = require("fs");

var _fs2 = _interopRequireDefault(_fs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var FELA_CONFIG_FILE = process.env.FELA_CONFIG_FILE ? process.env.FELA_CONFIG_FILE : "./fela.config.js";

exports.replaceRenderer = function (_ref) {
  var bodyComponent = _ref.bodyComponent,
      replaceBodyHTMLString = _ref.replaceBodyHTMLString,
      setHeadComponents = _ref.setHeadComponents;

  var config = void 0;
  try {
    if (_fs2.default.existsSync(FELA_CONFIG_FILE)) {
      config = eval(_fs2.default.readFileSync(FELA_CONFIG_FILE, 'utf8'));
    }
  } catch (err) {
    console.log(err);
  }
  var renderer = (0, _fela.createRenderer)(config);
  var bodyHTML = (0, _server.renderToString)(_react2.default.createElement(
    _reactFela.RendererProvider,
    { renderer: renderer },
    bodyComponent
  ));
  var sheetList = (0, _felaDom.renderToSheetList)(renderer);

  var elements = sheetList.map(function (_ref2) {
    var type = _ref2.type,
        css = _ref2.css,
        media = _ref2.media,
        support = _ref2.support;
    return _react2.default.createElement("style", {
      dangerouslySetInnerHTML: { __html: css },
      "data-fela-type": type,
      "data-fela-support": support,
      key: type + "-" + media,
      media: media
    });
  });
  replaceBodyHTMLString(bodyHTML);
  setHeadComponents(elements);
};
